(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'melon-core/classname/cxBuilder', './ripples/TouchRipple', 'lodash/omit'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('melon-core/classname/cxBuilder'), require('./ripples/TouchRipple'), require('lodash/omit'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.cxBuilder, global.TouchRipple, global.omit);
        global.Button = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _cxBuilder, _TouchRipple, _omit) {
    'use strict';

    exports.__esModule = true;
    exports.default = Button;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _TouchRipple2 = _interopRequireDefault(_TouchRipple);

    var _omit2 = _interopRequireDefault(_omit);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) {
        return typeof obj;
    } : function (obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };

    function _objectWithoutProperties(obj, keys) {
        var target = {};

        for (var i in obj) {
            if (keys.indexOf(i) >= 0) continue;
            if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
            target[i] = obj[i];
        }

        return target;
    }

    var cx = (0, _cxBuilder.create)('Button');

    /* eslint-disable fecs-prefer-class */

    /**
     * melon/Button
     *
     * @class
     * @param {Object}  props           属性
     * @param {boolean} props.disabled  是否不可点击
     * @param {boolean} props.hasRipple 是否有ripple动画
     * @return {ReactElement}
     */
    function Button(props) {
        var hasRipple = props.hasRipple,
            label = props.label,
            children = props.children,
            disabled = props.disabled,
            others = _objectWithoutProperties(props, ['hasRipple', 'label', 'children', 'disabled']);

        var className = cx(props).addVariants({
            icon: _react2.default.Children.count(children) === 1 && (typeof children === 'undefined' ? 'undefined' : _typeof(children)) === 'object' && children.type.displayName === 'Icon',
            ripple: hasRipple && !disabled
        }).build();

        return _react2.default.createElement(
            'button',
            _extends({}, (0, _omit2.default)(others, ['variants']), {
                disabled: disabled,
                className: className }),
            label || children,
            hasRipple && !disabled ? _react2.default.createElement(_TouchRipple2.default, null) : null
        );
    }
    /* eslint-enable fecs-prefer-class */

    Button.defaultProps = {
        hasRipple: true,
        disabled: false
    };

    Button.propTypes = {
        hasRipple: _propTypes2.default.bool,
        disabled: _propTypes2.default.bool
    };
});
//# sourceMappingURL=Button.js.map
