(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', './Mask', 'melon-core/classname/cxBuilder', './common/util/dom'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('./Mask'), require('melon-core/classname/cxBuilder'), require('./common/util/dom'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.Mask, global.cxBuilder, global.dom);
        global.Drawer = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _Mask, _cxBuilder, _dom) {
    'use strict';

    exports.__esModule = true;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _Mask2 = _interopRequireDefault(_Mask);

    var dom = _interopRequireWildcard(_dom);

    function _interopRequireWildcard(obj) {
        if (obj && obj.__esModule) {
            return obj;
        } else {
            var newObj = {};

            if (obj != null) {
                for (var key in obj) {
                    if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key];
                }
            }

            newObj.default = obj;
            return newObj;
        }
    }

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('Drawer');

    var REVERT_POSITION = {
        top: 'bottom',
        bottom: 'top',
        left: 'right',
        right: 'left'
    };

    /**
     * melon/Drawer
     *
     * @extends {React.Component}
     * @class
     */

    var Drawer = function (_Component) {
        _inherits(Drawer, _Component);

        function Drawer() {
            _classCallCheck(this, Drawer);

            return _possibleConstructorReturn(this, _Component.apply(this, arguments));
        }

        Drawer.prototype.render = function render() {
            var _props = this.props,
                children = _props.children,
                open = _props.open,
                position = _props.position,
                size = _props.size,
                mask = _props.mask,
                onHide = _props.onHide,
                maskClickClose = _props.maskClickClose;


            var posValue = open ? 0 : -size;

            if (size <= 0) {
                var clientSize = position === 'bottom' || position === 'top' ? dom.getClientHeight() : dom.getClientWidth();
                posValue = open ? -size : clientSize;
            }

            var style = size > 0 ? {
                top: position === 'bottom' ? null : posValue,
                bottom: position === 'top' ? null : posValue,
                left: position === 'right' ? null : posValue,
                right: position === 'left' ? null : posValue,
                height: position === 'bottom' || position === 'top' ? size : null,
                width: position === 'left' || position === 'right' ? size : null
            } : {
                top: position === 'bottom' ? posValue : 0,
                bottom: position === 'top' ? posValue : 0,
                left: position === 'right' ? posValue : 0,
                right: position === 'left' ? posValue : 0,
                height: null,
                width: null
            };

            var visibilityTransitionDelay = open ? '0ms' : '400ms';
            var transitionStyle = size > 0 ? position : REVERT_POSITION[position];

            var transition = '' + transitionStyle + ' 400ms cubic-bezier(0.23, 1, 0.32, 1) 0ms, ' + 'opacity 400ms cubic-bezier(0.23, 1, 0.32, 1) 0ms, ' + 'visibility 0ms cubic-bezier(0.23, 1, 0.32, 1) ' + visibilityTransitionDelay;

            var masker = mask ? _react2.default.createElement(_Mask2.default, {
                show: open,
                onClick: maskClickClose && onHide ? onHide : null }) : null;

            return _react2.default.createElement(
                'div',
                { className: cx(this.props).build() },
                _react2.default.createElement(
                    'div',
                    {
                        className: cx().part('window').build(),
                        style: _extends({}, style, {
                            opacity: open ? 1 : 0,
                            visibility: open ? 'visible' : 'hidden',
                            transition: transition,
                            WebkitTransition: transition,
                            MozTransition: transition,
                            msTransition: transition,
                            overflow: 'auto'
                        }) },
                    children
                ),
                masker
            );
        };

        return Drawer;
    }(_react.Component);

    exports.default = Drawer;


    Drawer.displayName = 'Drawer';

    /**
     * propTypes
     *
     * @property {number}   position       弹出的位置
     * @property {boolean}  open           是否打开
     * @property {number}   size           宽度
     * @property {boolean}  mask           是否需要遮罩
     * @property {boolean}  maskClickClose 是否点击遮罩以后关闭
     * @property {Function} onHide         关闭时调用
     */
    Drawer.propTypes = {
        position: _propTypes2.default.oneOf(Object.keys(REVERT_POSITION)).isRequired,
        open: _propTypes2.default.bool.isRequired,
        size: _propTypes2.default.number.isRequired,
        mask: _propTypes2.default.bool,
        maskClickClose: _propTypes2.default.bool,
        onHide: _propTypes2.default.func.isRequired
    };

    Drawer.defaultProps = {
        position: 'left',
        open: false,
        size: 300,
        mask: true,
        maskClickClose: true
    };
});
//# sourceMappingURL=Drawer.js.map
