(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'melon-core/classname/cxBuilder', 'react-dom'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('melon-core/classname/cxBuilder'), require('react-dom'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.cxBuilder, global.reactDom);
        global.Layer = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _cxBuilder, _reactDom) {
    'use strict';

    exports.__esModule = true;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('Layer');

    var Layer = function (_PureComponent) {
        _inherits(Layer, _PureComponent);

        function Layer() {
            _classCallCheck(this, Layer);

            for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
                args[_key] = arguments[_key];
            }

            var _this = _possibleConstructorReturn(this, _PureComponent.call.apply(_PureComponent, [this].concat(args)));

            _this.onClickAway = _this.onClickAway.bind(_this);
            _this.onMaskClick = _this.onMaskClick.bind(_this);
            return _this;
        }

        Layer.prototype.componentDidMount = function componentDidMount() {
            var _props = this.props,
                open = _props.open,
                useLayerMask = _props.useLayerMask;

            if (open) {
                this.addGlobalEventListeners(useLayerMask);
            }
        };

        Layer.prototype.componentWillReceiveProps = function componentWillReceiveProps(_ref) {
            var open = _ref.open,
                useLayerMask = _ref.useLayerMask;

            open ? this.addGlobalEventListeners(useLayerMask) : this.removeGlobalEventListeners(useLayerMask);
        };

        Layer.prototype.componentWillUnmount = function componentWillUnmount() {
            this.removeGlobalEventListeners(this.props.useLayerMask);
            if (this.container) {
                document.body.removeChild(this.container);
                this.container = null;
            }
        };

        Layer.prototype.onClickAway = function onClickAway(e) {
            var target = e.target,
                defaultPrevented = e.defaultPrevented;
            var _props2 = this.props,
                onClickAway = _props2.onClickAway,
                open = _props2.open;

            if (defaultPrevented || !open || !this.container) {
                return;
            }
            if (!this.container.contains(target)) {
                onClickAway && onClickAway();
            }
        };

        Layer.prototype.onMaskClick = function onMaskClick(e) {
            if (e.target !== e.currentTarget) {
                return;
            }
            var onClickAway = this.props.onClickAway;

            if (onClickAway) {
                onClickAway(e);
            }
        };

        Layer.prototype.addGlobalEventListeners = function addGlobalEventListeners(useLayerMask) {
            var _this2 = this;

            if (!useLayerMask) {
                setTimeout(function () {
                    window.addEventListener('click', _this2.onClickAway);
                }, 0);
            }
        };

        Layer.prototype.removeGlobalEventListeners = function removeGlobalEventListeners(useLayerMask) {
            if (!useLayerMask) {
                window.removeEventListener('click', this.onClickAway);
            }
        };

        Layer.prototype.getLayer = function getLayer() {
            var _props3 = this.props,
                open = _props3.open,
                useLayerMask = _props3.useLayerMask;

            var container = this.container;

            if (!open || !container) {
                return null;
            }

            return useLayerMask ? container.firstChild : container;
        };

        Layer.prototype.getContainer = function getContainer() {
            var container = this.container;
            if (!container) {
                container = this.container = document.createElement('div');
                document.body.appendChild(container);
            }
            return container;
        };

        Layer.prototype.render = function render() {
            var _props4 = this.props,
                open = _props4.open,
                children = _props4.children,
                useLayerMask = _props4.useLayerMask;

            return open ? (0, _reactDom.createPortal)(useLayerMask ? _react2.default.createElement(
                'div',
                {
                    className: 'ui-layer-mask',
                    onClick: this.onMaskClick },
                children
            ) : children, this.getContainer()) : null;
        };

        return Layer;
    }(_react.PureComponent);

    exports.default = Layer;


    Layer.propTypes = {
        onClickAway: _propTypes2.default.func.isRequired,
        open: _propTypes2.default.bool.isRequired,
        useLayerMask: _propTypes2.default.bool.isRequired
    };

    Layer.defaultProps = {
        open: false,
        useLayerMask: true
    };
});
//# sourceMappingURL=Layer.js.map
