(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', './Table', './table/SelectorColumn', './table/SelectorRow'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('./Table'), require('./table/SelectorColumn'), require('./table/SelectorRow'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.Table, global.SelectorColumn, global.SelectorRow);
        global.SelectableTable = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _Table2, _SelectorColumn, _SelectorRow) {
    'use strict';

    exports.__esModule = true;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _Table3 = _interopRequireDefault(_Table2);

    var _SelectorColumn2 = _interopRequireDefault(_SelectorColumn);

    var _SelectorRow2 = _interopRequireDefault(_SelectorRow);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    function getNextSelectedRowData(multiple, dataSource, current, action, rowIndex) {

        if (!multiple) {
            return [rowIndex];
        }

        if (action === 'selectAll') {
            return dataSource.map(function (_, index) {
                return index;
            });
        }

        if (action === 'unselectAll') {
            return [];
        }

        var selected = action === 'select' ? current.concat(rowIndex).sort() : current.filter(function (row) {
            return row !== rowIndex;
        });

        return selected;
    }

    /**
     * 可选择行的表格
     *
     * @extends {Table}
     */

    var SelectableTable = function (_Table) {
        _inherits(SelectableTable, _Table);

        /**
         * 构造函数
         *
         * @public
         * @param  {*} props 属性
         */
        function SelectableTable(props) {
            _classCallCheck(this, SelectableTable);

            var _this = _possibleConstructorReturn(this, _Table.call(this, props));

            _this.getSelected = _this.getSelected.bind(_this);
            _this.isAllRowsSelected = _this.isAllRowsSelected.bind(_this);
            _this.isRowSelected = _this.isRowSelected.bind(_this);
            _this.onSelect = _this.onSelect.bind(_this);
            _this.onSelectAll = _this.onSelectAll.bind(_this);

            _this.state = _extends({}, _this.state, {
                selected: _this.props.selected
            });

            return _this;
        }

        /**
         * 接受新属性时处理函数
         *
         * @public
         * @param  {*} props 新属性
         */


        SelectableTable.prototype.componentWillReceiveProps = function componentWillReceiveProps(props) {

            _Table.prototype.componentWillReceiveProps.call(this, props);

            var selected = props.selected,
                onSelect = props.onSelect;


            if (onSelect && selected != null) {
                this.setState({
                    selected: selected
                });
            }
        };

        SelectableTable.prototype.onSelect = function onSelect(rowIndex) {
            this.onRowSelectorClick(this.isRowSelected(rowIndex) ? 'unselect' : 'select', rowIndex);
        };

        SelectableTable.prototype.onSelectAll = function onSelectAll() {
            this.onRowSelectorClick(this.isAllRowsSelected() ? 'unselectAll' : 'selectAll');
        };

        SelectableTable.prototype.onRowSelectorClick = function onRowSelectorClick(action, rowIndex) {
            var _props = this.props,
                onSelect = _props.onSelect,
                dataSource = _props.dataSource,
                multiple = _props.multiple;


            var selected = this.getSelected();

            selected = getNextSelectedRowData(multiple, dataSource, selected, action, rowIndex);

            if (onSelect) {
                onSelect({
                    selected: selected,
                    target: this
                });
                return;
            }

            this.setState({
                selected: selected
            });
        };

        SelectableTable.prototype.getSelected = function getSelected() {
            var source = this.props.onSelect ? this.props : this.state;
            return source.selected;
        };

        SelectableTable.prototype.isRowSelected = function isRowSelected(rowIndex) {
            var selectedRows = this.getSelected();
            return selectedRows.indexOf(rowIndex) !== -1;
        };

        SelectableTable.prototype.isAllRowsSelected = function isAllRowsSelected() {
            var selectedRows = this.getSelected();
            return selectedRows.length === this.props.dataSource.length;
        };

        SelectableTable.prototype.getColumns = function getColumns(props) {

            var selectorColumn = _react2.default.createElement(_SelectorColumn2.default, {
                isSelected: this.isRowSelected,
                isAllSelected: this.isAllRowsSelected,
                multiple: props.multiple,
                onSelect: this.onSelect,
                onSelectAll: this.onSelectAll });

            var columns = _Table.prototype.getColumns.call(this, props);

            return [selectorColumn].concat(columns);
        };

        SelectableTable.prototype.renderRow = function renderRow(part, columns, rowData, index, tableWidth) {
            var _props2 = this.props,
                rowHeight = _props2.rowHeight,
                headerRowHeight = _props2.headerRowHeight,
                highlight = _props2.highlight,
                rowHasChanged = _props2.rowHasChanged;

            return _react2.default.createElement(_SelectorRow2.default, {
                selected: part === 'body' ? this.isRowSelected(index) : this.isAllRowsSelected(),
                height: part === 'body' ? rowHeight : headerRowHeight,
                highlight: highlight,
                key: index,
                rowIndex: index,
                part: part,
                columns: columns,
                data: rowData,
                tableWidth: tableWidth,
                rowHasChanged: rowHasChanged });
        };

        return SelectableTable;
    }(_Table3.default);

    exports.default = SelectableTable;


    SelectableTable.displayName = 'SelectableTable';

    SelectableTable.propTypes = _extends({}, _Table3.default.propTypes, {
        multiple: _propTypes2.default.bool.isRequired,
        onSelect: _propTypes2.default.func,
        selected: _propTypes2.default.arrayOf(_propTypes2.default.number).isRequired
    });

    SelectableTable.defaultProps = _extends({}, _Table3.default.defaultProps, {
        multiple: true,
        selected: []
    });
});
//# sourceMappingURL=SelectableTable.js.map
