(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'react-dom', 'melon-core/InputComponent', 'melon-core/classname/cxBuilder', './slider/Bar', './slider/getNewValue'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('react-dom'), require('melon-core/InputComponent'), require('melon-core/classname/cxBuilder'), require('./slider/Bar'), require('./slider/getNewValue'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.reactDom, global.InputComponent, global.cxBuilder, global.Bar, global.getNewValue);
        global.Slider = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _reactDom, _InputComponent2, _cxBuilder, _Bar, _getNewValue) {
    'use strict';

    exports.__esModule = true;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _reactDom2 = _interopRequireDefault(_reactDom);

    var _InputComponent3 = _interopRequireDefault(_InputComponent2);

    var _Bar2 = _interopRequireDefault(_Bar);

    var _getNewValue2 = _interopRequireDefault(_getNewValue);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('Slider');

    /**
     * melon/Slider
     *
     * @extends {melon-core/InputComponent}
     * @class
     */

    var Slider = function (_InputComponent) {
        _inherits(Slider, _InputComponent);

        /**
         * 构造函数
         *
         * @public
         * @constructor
         * @param  {*} props   属性
         * @param  {*} context 上下文
         */
        function Slider(props, context) {
            _classCallCheck(this, Slider);

            var _this = _possibleConstructorReturn(this, _InputComponent.call(this, props, context));

            _this.onMouseDown = _this.onMouseDown.bind(_this);
            _this.onMouseUp = _this.onMouseUp.bind(_this);
            _this.onMouseChange = _this.onMouseChange.bind(_this);

            var maximum = props.maximum,
                minimum = props.minimum;

            var value = _this.state.value;

            _this.state.value = value > maximum ? maximum : value;
            _this.state.value = value < minimum ? minimum : value;

            /**
             * 状态
             *
             * @protected
             * @type {Object}
             */
            _this.state = _extends({}, _this.state, {
                active: false
            });
            return _this;
        }

        /**
         * 将要Unmount时的处理
         *
         * @public
         * @override
         */


        Slider.prototype.componentWillUnmount = function componentWillUnmount() {

            /**
             * bar
             *
             * @protected
             * @type {HTMLElement}
             */
            this.slider = null;
        };

        Slider.prototype.onMouseUp = function onMouseUp() {
            window.removeEventListener('mouseup', this.onMouseUp);
            window.removeEventListener('mousemove', this.onMouseChange);
            this.setState({ active: false });
        };

        Slider.prototype.onMouseChange = function onMouseChange(e) {

            var clientX = e.clientX;

            var _props = this.props,
                maximum = _props.maximum,
                minimum = _props.minimum,
                step = _props.step;

            var value = this.state.value;

            var newValue = (0, _getNewValue2.default)(this.slider, clientX, maximum, minimum, step);

            if (value === newValue || newValue > maximum || newValue < minimum) {
                return;
            }

            this.onSliderChange(newValue);
        };

        Slider.prototype.onSliderChange = function onSliderChange(newValue) {
            _InputComponent.prototype.onChange.call(this, {
                type: 'change',
                target: this,
                value: newValue
            });
        };

        Slider.prototype.onMouseDown = function onMouseDown(e) {

            if (this.props.disable || this.props.readOnly || e.button !== 0) {
                return;
            }

            window.addEventListener('mouseup', this.onMouseUp);
            window.addEventListener('mousemove', this.onMouseChange);

            this.onMouseChange(e);

            this.setState({ active: true });
        };

        Slider.prototype.getSliderValue = function getSliderValue() {
            return this.state.value;
        };

        Slider.prototype.renderHiddenInput = function renderHiddenInput() {

            var value = this.state.value;

            return _react2.default.createElement('input', {
                type: 'hidden',
                value: value });
        };

        Slider.prototype.renderBar = function renderBar() {
            var _this2 = this;

            return _react2.default.createElement(_Bar2.default, _extends({}, this.props, {
                ref: function ref(slider) {
                    _this2.slider = _reactDom2.default.findDOMNode(slider);
                },
                active: this.state.active,
                onMouseDown: this.onMouseDown,
                value: this.getSliderValue() }));
        };

        Slider.prototype.render = function render() {
            var _props2 = this.props,
                width = _props2.width,
                _props2$style = _props2.style,
                style = _props2$style === undefined ? {} : _props2$style;


            var className = cx(this.props).addStates(this.getStyleStates()).build();

            return _react2.default.createElement(
                'div',
                {
                    style: _extends({}, style, { width: width }),
                    className: className },
                this.renderHiddenInput(),
                this.renderBar()
            );
        };

        return Slider;
    }(_InputComponent3.default);

    exports.default = Slider;


    Slider.displayName = 'Slider';

    Slider.defaultProps = _extends({}, _InputComponent3.default.defaultProps, {
        defaultValue: 0,
        maximum: 100,
        minimum: 0,
        step: 1,
        width: '100%',
        height: 2
    });

    Slider.propTypes = _extends({}, _InputComponent3.default.propTypes, {
        defaultValue: _propTypes2.default.number,
        value: _propTypes2.default.number,
        maximum: _propTypes2.default.number,
        minimum: _propTypes2.default.number,
        width: _propTypes2.default.oneOfType([_propTypes2.default.number, _propTypes2.default.string]),
        height: _propTypes2.default.oneOfType([_propTypes2.default.number, _propTypes2.default.string]),
        pointerSize: _propTypes2.default.oneOfType([_propTypes2.default.number, _propTypes2.default.string])
    });
});
//# sourceMappingURL=Slider.js.map
