(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'react-dom', './textbox/FloatLabel', './textbox/Input', 'melon-core/InputComponent', 'melon-core/classname/cxBuilder'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('react-dom'), require('./textbox/FloatLabel'), require('./textbox/Input'), require('melon-core/InputComponent'), require('melon-core/classname/cxBuilder'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.reactDom, global.FloatLabel, global.Input, global.InputComponent, global.cxBuilder);
        global.TextBox = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _reactDom, _FloatLabel, _Input, _InputComponent2, _cxBuilder) {
    'use strict';

    exports.__esModule = true;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _reactDom2 = _interopRequireDefault(_reactDom);

    var _FloatLabel2 = _interopRequireDefault(_FloatLabel);

    var _Input2 = _interopRequireDefault(_Input);

    var _InputComponent3 = _interopRequireDefault(_InputComponent2);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    function _objectWithoutProperties(obj, keys) {
        var target = {};

        for (var i in obj) {
            if (keys.indexOf(i) >= 0) continue;
            if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
            target[i] = obj[i];
        }

        return target;
    }

    var _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('TextBox');

    function getValueStringLength(value) {
        return value == null ? 0 : ('' + value).length;
    }

    /**
     * melon/TextBox
     *
     * @extends {React.Component}
     * @class
     */

    var TextBox = function (_InputComponent) {
        _inherits(TextBox, _InputComponent);

        /**
         * 构造函数
         *
         * @public
         * @constructor
         * @param  {*} props   属性
         * @param  {*} context 上下文
         */
        function TextBox(props, context) {
            _classCallCheck(this, TextBox);

            var _this = _possibleConstructorReturn(this, _InputComponent.call(this, props, context));

            /**
             * 状态
             *
             * @private
             * @type {Object}
             */
            _this.state = _extends({}, _this.state, {
                isFocus: false
            });

            _this.onFocus = _this.onFocus.bind(_this);
            _this.onBlur = _this.onBlur.bind(_this);
            _this.onChange = _this.onChange.bind(_this);

            return _this;
        }

        /**
         * Mount时的处理
         *
         * @public
         * @override
         */


        TextBox.prototype.componentDidMount = function componentDidMount() {

            _InputComponent.prototype.componentDidMount.call(this);

            var _props = this.props,
                multiline = _props.multiline,
                autoFocus = _props.autoFocus;


            if (multiline && this.state.value != null) {
                this.syncTextareaHeight();
            }

            if (autoFocus) {
                this.input.focus();
            }
        };

        TextBox.prototype.componentDidUpdate = function componentDidUpdate() {

            var props = this.props;

            if (
            // 多行的
            props.multiline
            // 控制的
            && !props.hasOwnProperty('defaultValue')) {
                // 同步高度
                this.syncTextareaHeight();
            }
        };

        TextBox.prototype.onFocus = function onFocus(e) {

            this.setState({
                isFocus: true
            });

            var onFocus = this.props.onFocus;

            if (onFocus) {
                onFocus({
                    type: 'focus',
                    target: this
                });
                return;
            }
        };

        TextBox.prototype.onBlur = function onBlur(e) {

            this.setState({
                isFocus: false
            });

            var onBlur = this.props.onBlur;

            if (onBlur) {
                onBlur({
                    type: 'blur',
                    target: this
                });
            }
        };

        TextBox.prototype.onChange = function onChange(e) {
            var _this2 = this;

            var currentValue = this.state.value;

            _InputComponent.prototype.onChange.call(this, {
                value: e.target.value,
                target: e.target,
                currentTarget: this,
                type: 'change'
            }, function () {
                if (_this2.props.multiline && _this2.props.hasOwnProperty('defaultValue') && currentValue !== _this2.state.value) {
                    _this2.syncTextareaHeight();
                }
            });
        };

        TextBox.prototype.syncTextareaHeight = function syncTextareaHeight() {

            var input = this.input;

            if (input) {
                input.style.height = 'auto';
                input.style.height = input.scrollHeight + 'px';
            }
        };

        TextBox.prototype.renderFloatingLabel = function renderFloatingLabel(floatingLabel, isFloating, isFocus) {

            if (!floatingLabel) {
                return null;
            }

            return _react2.default.createElement(_FloatLabel2.default, {
                floating: isFloating || isFocus,
                focused: isFocus,
                label: floatingLabel });
        };

        TextBox.prototype.render = function render() {
            var _this3 = this;

            var onFocus = this.onFocus,
                onBlur = this.onBlur,
                onChange = this.onChange,
                props = this.props;

            var floatingLabel = props.floatingLabel,
                defaultValue = props.defaultValue,
                rest = _objectWithoutProperties(props, ['floatingLabel', 'defaultValue']);

            var _state = this.state,
                isFocus = _state.isFocus,
                _state$value = _state.value,
                value = _state$value === undefined ? defaultValue : _state$value;


            var floating = !!getValueStringLength(value) || isFocus;

            var className = cx(props).addStates({
                floating: floatingLabel && floating,
                focus: isFocus,
                fulfilled: value == null
            }).addStates(this.getStyleStates()).build();

            return _react2.default.createElement(
                'div',
                { className: className },
                this.renderFloatingLabel(floatingLabel, floating, isFocus),
                _react2.default.createElement(_Input2.default, _extends({}, rest, {
                    onFocus: onFocus,
                    onBlur: onBlur,
                    onChange: onChange,
                    isFocus: isFocus,
                    value: value == null ? '' : value,
                    ref: function ref(input) {
                        if (input) {
                            _this3.input = _reactDom2.default.findDOMNode(input);
                        }
                    } }))
            );
        };

        return TextBox;
    }(_InputComponent3.default);

    exports.default = TextBox;


    TextBox.displayName = 'TextBox';

    TextBox.defaultProps = {
        type: 'text'
    };

    TextBox.propTypes = {
        type: _propTypes2.default.oneOf(['text', 'password', 'number']),
        placeholder: _propTypes2.default.string,
        floatingLabel: _propTypes2.default.string,
        multiline: _propTypes2.default.bool,
        autoFocus: _propTypes2.default.bool
    };

    TextBox.contextTypes = _InputComponent3.default.contextTypes;
});
//# sourceMappingURL=TextBox.js.map
