(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'melon-core/InputComponent', 'melon-core/classname/cxBuilder', './ripples/CenterRipple'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('melon-core/InputComponent'), require('melon-core/classname/cxBuilder'), require('./ripples/CenterRipple'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.InputComponent, global.cxBuilder, global.CenterRipple);
        global.Toggle = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _InputComponent2, _cxBuilder, _CenterRipple) {
    'use strict';

    exports.__esModule = true;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _InputComponent3 = _interopRequireDefault(_InputComponent2);

    var _CenterRipple2 = _interopRequireDefault(_CenterRipple);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('Toggle');

    /**
     * melon/Toggle
     *
     * @extends {melon-core/InputComponent}
     * @class
     */

    var Toggle = function (_InputComponent) {
        _inherits(Toggle, _InputComponent);

        /**
         * 构造函数
         *
         * @public
         * @constructor
         * @param  {*} props   属性
         * @param  {*} context 上下文
         */
        function Toggle(props, context) {
            _classCallCheck(this, Toggle);

            var _this = _possibleConstructorReturn(this, _InputComponent.call(this, props, context));

            _this.onChange = _this.onChange.bind(_this);

            return _this;
        }

        /**
         * 值改变处理
         *
         * @protected
         * @param  {Object} e 事件对象
         */


        Toggle.prototype.onChange = function onChange(e) {
            var _props = this.props,
                disabled = _props.disabled,
                readOnly = _props.readOnly,
                trueValue = _props.trueValue,
                falseValue = _props.falseValue;


            if (disabled || readOnly) {
                return;
            }

            _InputComponent.prototype.onChange.call(this, {
                type: 'change',
                target: this,
                value: e.target.checked ? trueValue : falseValue
            });
        };

        Toggle.prototype.render = function render() {
            var props = this.props,
                state = this.state,
                onChange = this.onChange;


            var value = state.value;

            var name = props.name,
                trueValue = props.trueValue,
                disabled = props.disabled;


            var checked = value === trueValue;

            return _react2.default.createElement(
                'label',
                { className: cx(props).addStates({ checked: checked }).build() },
                _react2.default.createElement('input', {
                    type: 'checkbox',
                    name: name,
                    value: value,
                    onChange: onChange,
                    checked: checked }),
                _react2.default.createElement(
                    'div',
                    { className: cx().part('bar-container').build() },
                    _react2.default.createElement('div', { className: cx().part('bar').build() }),
                    _react2.default.createElement(
                        'div',
                        { className: cx().part('circle').build() },
                        disabled ? null : _react2.default.createElement(_CenterRipple2.default, { flag: checked, scale: 2.5, opacity: 0.3 })
                    )
                )
            );
        };

        return Toggle;
    }(_InputComponent3.default);

    exports.default = Toggle;


    Toggle.displayName = 'Toggle';

    Toggle.defaultProps = _extends({}, _InputComponent3.default.defaultProps, {
        trueValue: 'on',
        falseValue: ''
    });

    Toggle.propTypes = _extends({}, _InputComponent3.default.propTypes, {
        trueValue: _propTypes2.default.any.isRequired
    });

    Toggle.childContextTypes = _InputComponent3.default.childContextTypes;
    Toggle.contextTypes = _InputComponent3.default.contextTypes;
});
//# sourceMappingURL=Toggle.js.map
