(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'react-dom', 'melon-core/classname/cxBuilder', './tree/TreeNode'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('react-dom'), require('melon-core/classname/cxBuilder'), require('./tree/TreeNode'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.reactDom, global.cxBuilder, global.TreeNode);
        global.Tree = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _reactDom, _cxBuilder, _TreeNode) {
    'use strict';

    exports.__esModule = true;
    exports.TreeNode = undefined;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _reactDom2 = _interopRequireDefault(_reactDom);

    var _TreeNode2 = _interopRequireDefault(_TreeNode);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    function _objectWithoutProperties(obj, keys) {
        var target = {};

        for (var i in obj) {
            if (keys.indexOf(i) >= 0) continue;
            if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
            target[i] = obj[i];
        }

        return target;
    }

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('Tree');

    exports.TreeNode = _TreeNode2.default;

    var Tree = function (_Component) {
        _inherits(Tree, _Component);

        /**
         * 构造函数
         *
         * @public
         * @constructor
         * @param  {*} props   属性
         */
        function Tree(props) {
            _classCallCheck(this, Tree);

            var _this = _possibleConstructorReturn(this, _Component.call(this, props));

            _this.onTreeNodeClick = _this.onTreeNodeClick.bind(_this);
            return _this;
        }

        /**
         * 节点点击的处理
         *
         * @protected
         * @param  {Object} e 事件对象
         */


        Tree.prototype.onTreeNodeClick = function onTreeNodeClick(e) {

            var target = e.currentTarget;
            var main = _reactDom2.default.findDOMNode(this);

            e.stopPropagation();

            var elements = main.querySelectorAll('[data-role=tree-node]');

            for (var i = 0, len = elements.length; i < len; ++i) {

                elements[i].className = elements[i].className.split(' ').filter(function (className) {
                    return className !== 'state-selected';
                }).join(' ');
            }

            target.className += ' state-selected';
        };

        Tree.prototype.renderTreeNode = function renderTreeNode(children, level) {
            var _this2 = this;

            var expand = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;


            if (!children) {
                return;
            }

            return _react.Children.map(children, function (child, index) {
                return (0, _react.cloneElement)(child, {
                    onClick: _this2.onTreeNodeClick,
                    key: index,
                    level: level,
                    expand: expand
                }, _react.Children.count(child.props.children) ? _this2.renderTreeNode(child.props.children, level + 1, expand) : null);
            });
        };

        Tree.prototype.render = function render() {
            var _props = this.props,
                children = _props.children,
                variants = _props.variants,
                states = _props.states,
                defaultExpandAll = _props.defaultExpandAll,
                rest = _objectWithoutProperties(_props, ['children', 'variants', 'states', 'defaultExpandAll']);

            var className = cx().addVariants(variants).addStates(states).build();

            return _react2.default.createElement(
                'ul',
                _extends({}, rest, { className: className }),
                this.renderTreeNode(children, 1, defaultExpandAll)
            );
        };

        return Tree;
    }(_react.Component);

    exports.default = Tree;


    Tree.TreeNode = _TreeNode2.default;

    Tree.createTreeNodes = function (datasource) {
        var level = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;

        if (datasource == null) {
            return null;
        }
        return datasource.map(function (item, index) {
            return _react2.default.createElement(
                _TreeNode2.default,
                {
                    level: level,
                    label: item.text,
                    key: item.id || index },
                Tree.createTreeNodes(item.children, level + 1)
            );
        });
    };

    Tree.displayName = 'Tree';

    Tree.propTypes = {
        defaultExpandAll: _propTypes2.default.bool,
        datasource: _propTypes2.default.array
    }, Tree.defaultProps = {

        /**
         * 默认展开树
         * @type {Boolean}
         */
        defaultExpandAll: false

    };
});
//# sourceMappingURL=Tree.js.map
