(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'melon-core/classname/cxBuilder', '../Icon', '../ripples/CenterRipple'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('melon-core/classname/cxBuilder'), require('../Icon'), require('../ripples/CenterRipple'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.cxBuilder, global.Icon, global.CenterRipple);
        global.Option = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _cxBuilder, _Icon, _CenterRipple) {
    'use strict';

    exports.__esModule = true;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _Icon2 = _interopRequireDefault(_Icon);

    var _CenterRipple2 = _interopRequireDefault(_CenterRipple);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('BoxGroupOption');

    var BoxGroupOption = function (_Component) {
        _inherits(BoxGroupOption, _Component);

        function BoxGroupOption(props) {
            _classCallCheck(this, BoxGroupOption);

            var _this = _possibleConstructorReturn(this, _Component.call(this, props));

            _this.onClick = _this.onClick.bind(_this);
            return _this;
        }

        BoxGroupOption.prototype.onClick = function onClick() {
            this.refs.ripple && this.refs.ripple.animate();
        };

        BoxGroupOption.prototype.getIcon = function getIcon(boxModel, isChecked) {
            return BoxGroupOption.Icons[boxModel][isChecked ? 'checked' : 'unchecked'];
        };

        BoxGroupOption.prototype.render = function render() {

            var props = this.props;

            var boxModel = props.boxModel,
                checked = props.checked,
                disabled = props.disabled,
                readOnly = props.readOnly,
                onChange = props.onChange;


            var className = cx(props).addStates({ checked: checked }).build();
            var icon = this.getIcon(boxModel, checked);

            return _react2.default.createElement(
                'label',
                { className: className, onClick: disabled || readOnly ? null : this.onClick },
                _react2.default.createElement('input', {
                    disabled: disabled,
                    checked: checked,
                    type: props.boxModel,
                    value: props.value,
                    readOnly: readOnly,
                    name: props.name,
                    onChange: readOnly ? null : onChange }),
                _react2.default.createElement(
                    _Icon2.default,
                    { icon: icon },
                    disabled || readOnly ? null : _react2.default.createElement(_CenterRipple2.default, { ref: 'ripple' })
                ),
                props.label
            );
        };

        return BoxGroupOption;
    }(_react.Component);

    exports.default = BoxGroupOption;


    BoxGroupOption.displayName = 'BoxGroupOption';

    BoxGroupOption.propTypes = {
        boxModel: _propTypes2.default.oneOf(['radio', 'checkbox']).isRequired,
        label: _propTypes2.default.string,
        value: _propTypes2.default.string,
        checked: _propTypes2.default.bool,
        name: _propTypes2.default.string,
        disabled: _propTypes2.default.bool,
        onChange: _propTypes2.default.func.isRequired
    };

    BoxGroupOption.Icons = {
        radio: {
            checked: 'radio-button-checked',
            unchecked: 'radio-button-unchecked'
        },
        checkbox: {
            checked: 'check-box',
            unchecked: 'check-box-outline-blank'
        }
    };
});
//# sourceMappingURL=Option.js.map
