(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'react-dom', './RippleCircle', '../common/util/dom', 'melon-core/classname/cxBuilder', 'react-motion'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('react-dom'), require('./RippleCircle'), require('../common/util/dom'), require('melon-core/classname/cxBuilder'), require('react-motion'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.reactDom, global.RippleCircle, global.dom, global.cxBuilder, global.reactMotion);
        global.TouchRipple = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _reactDom, _RippleCircle, _dom, _cxBuilder, _reactMotion) {
    'use strict';

    exports.__esModule = true;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _reactDom2 = _interopRequireDefault(_reactDom);

    var _RippleCircle2 = _interopRequireDefault(_RippleCircle);

    var dom = _interopRequireWildcard(_dom);

    function _interopRequireWildcard(obj) {
        if (obj && obj.__esModule) {
            return obj;
        } else {
            var newObj = {};

            if (obj != null) {
                for (var key in obj) {
                    if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key];
                }
            }

            newObj.default = obj;
            return newObj;
        }
    }

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('TouchRipple');

    var TouchRipple = function (_Component) {
        _inherits(TouchRipple, _Component);

        function TouchRipple(props) {
            _classCallCheck(this, TouchRipple);

            var _this = _possibleConstructorReturn(this, _Component.call(this, props));

            _this.state = {
                now: 't' + 0,
                center: [0, 0]
            };

            _this.onMouseDown = _this.onMouseDown.bind(_this);
            _this.willLeave = _this.willLeave.bind(_this);
            return _this;
        }

        TouchRipple.prototype.onMouseDown = function onMouseDown(_ref) {
            var pageX = _ref.pageX,
                pageY = _ref.pageY;


            this.setState({
                center: this.getCenter(pageX, pageY),
                now: 't' + new Date().getTime()
            });
        };

        TouchRipple.prototype.sholdComponentUpdate = function sholdComponentUpdate(nextProps, nextState) {
            var props = this.props,
                state = this.state;

            return props.opacity !== nextProps.opacity || state.now !== nextState.now;
        };

        TouchRipple.prototype.getCenter = function getCenter(pageX, pageY) {

            var main = _reactDom2.default.findDOMNode(this);
            var position = dom.getPosition(main);
            var radius = Math.max(position.width, position.height) / 2;

            this.radius = radius;

            return [pageX - position.left - radius, pageY - position.top - radius];
        };

        TouchRipple.prototype.willLeave = function willLeave(key, valOfKey) {
            return _extends({}, valOfKey, {
                opacity: (0, _reactMotion.spring)(0, { stiffness: 60, damping: 15 }),
                scale: (0, _reactMotion.spring)(2, { stiffness: 60, damping: 15 })
            });
        };

        TouchRipple.prototype.render = function render() {
            var _this2 = this;

            var _state = this.state,
                _state$center = _state.center,
                centerX = _state$center[0],
                centerY = _state$center[1],
                now = _state.now;


            var styles = [{
                key: now,
                style: {
                    opacity: (0, _reactMotion.spring)(this.props.opacity),
                    scale: (0, _reactMotion.spring)(0)
                }
            }];

            var circleClassName = cx().part('circle').build();

            return _react2.default.createElement(
                _reactMotion.TransitionMotion,
                {
                    willLeave: this.willLeave,
                    styles: styles,
                    didLeave: this.props.onMotionEnd },
                function (interpolatedStyles) {
                    return _react2.default.createElement(
                        'div',
                        {
                            onMouseDown: _this2.onMouseDown,
                            className: cx(_this2.props).build() },
                        interpolatedStyles.map(function (config) {
                            var _config$style = config.style,
                                opacity = _config$style.opacity,
                                scale = _config$style.scale;

                            return _react2.default.createElement(_RippleCircle2.default, {
                                key: config.key,
                                className: circleClassName,
                                opacity: opacity,
                                scale: scale,
                                style: {
                                    width: _this2.radius * 2 || 0,
                                    height: _this2.radius * 2 || 0,
                                    left: centerX,
                                    top: centerY
                                } });
                        })
                    );
                }
            );
        };

        return TouchRipple;
    }(_react.Component);

    exports.default = TouchRipple;


    TouchRipple.defaultProps = {
        opacity: 0.3
    };

    TouchRipple.propTypes = {
        opacity: _propTypes2.default.number,
        onMotionEnd: _propTypes2.default.func
    };
});
//# sourceMappingURL=TouchRipple.js.map
