(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'prop-types', 'melon-core/classname/cxBuilder', '../Icon', 'lodash/omit'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('prop-types'), require('melon-core/classname/cxBuilder'), require('../Icon'), require('lodash/omit'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.propTypes, global.cxBuilder, global.Icon, global.omit);
        global.TreeNode = mod.exports;
    }
})(this, function (exports, _react, _propTypes, _cxBuilder, _Icon, _omit) {
    'use strict';

    exports.__esModule = true;

    var _react2 = _interopRequireDefault(_react);

    var _propTypes2 = _interopRequireDefault(_propTypes);

    var _Icon2 = _interopRequireDefault(_Icon);

    var _omit2 = _interopRequireDefault(_omit);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    function _objectWithoutProperties(obj, keys) {
        var target = {};

        for (var i in obj) {
            if (keys.indexOf(i) >= 0) continue;
            if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
            target[i] = obj[i];
        }

        return target;
    }

    function _classCallCheck(instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    }

    function _possibleConstructorReturn(self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    }

    function _inherits(subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    }

    var cx = (0, _cxBuilder.create)('TreeNode');

    var TreeNode = function (_Component) {
        _inherits(TreeNode, _Component);

        function TreeNode(props) {
            _classCallCheck(this, TreeNode);

            var _this = _possibleConstructorReturn(this, _Component.call(this, props));

            _this.onClick = _this.onClick.bind(_this);

            _this.state = {
                expand: props.expand || false
            };

            return _this;
        }

        TreeNode.prototype.shouldComponentUpdate = function shouldComponentUpdate(nextProps, nextState) {
            return nextState.expand !== this.state.expand;
        };

        TreeNode.prototype.componentWillReceiveProps = function componentWillReceiveProps(props) {

            if (props.expand === this.props.expand) {
                return;
            }

            this.setState({ expand: props.expand });
        };

        TreeNode.prototype.onClick = function onClick(e) {
            this.setState({ expand: !this.state.expand });
        };

        TreeNode.prototype.render = function render() {

            var props = this.props;

            var label = props.label,
                variants = props.variants,
                states = props.states,
                expandIcon = props.expandIcon,
                unexpandIcon = props.unexpandIcon,
                children = props.children,
                level = props.level,
                icons = props.icons,
                others = _objectWithoutProperties(props, ['label', 'variants', 'states', 'expandIcon', 'unexpandIcon', 'children', 'level', 'icons']);

            var expand = this.state.expand;

            var icon = expand ? expandIcon || icons[1] : unexpandIcon || icons[0];

            var iconStyle = void 0;
            var labelStyle = void 0;

            if (level) {
                labelStyle = {
                    paddingLeft: level * 1.2 + 0.4 + 'em'
                };
                iconStyle = {
                    left: 0.25 + (level - 1) * 1.2 + 'em'
                };
            }

            // 是否还有子节点
            if (_react.Children.count(children) > 0) {
                children = [_react2.default.createElement(_Icon2.default, {
                    key: 'icon',
                    icon: icon,
                    onClick: this.onClick,
                    style: iconStyle }), _react2.default.createElement(
                    'span',
                    {
                        onClick: this.onClick,
                        key: 'label',
                        'data-role': 'tree-node-label',
                        style: labelStyle,
                        className: cx().part('label').addVariants('parent').addStates({ expand: expand }).build() },
                    label
                ), _react2.default.createElement(
                    'ul',
                    {
                        className: cx().part('root').addStates({ expand: expand }).build(),
                        key: 'root',
                        ref: 'list' },
                    children
                )];
            } else {
                children = _react2.default.createElement(
                    'span',
                    {
                        onClick: this.onClick,
                        key: 'label',
                        'data-role': 'tree-node-label',
                        style: labelStyle,
                        className: cx().part('label').build() },
                    label
                );
            }

            var className = cx(props).addVariants(variants).addVariants('level' + props.level).addStates(states).build();

            return _react2.default.createElement(
                'li',
                _extends({}, (0, _omit2.default)(others, ['expand']), {
                    'data-role': 'tree-node',
                    className: className }),
                children
            );
        };

        return TreeNode;
    }(_react.Component);

    exports.default = TreeNode;


    TreeNode.propTypes = {
        label: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.element]),
        expandIcon: _propTypes2.default.string,
        unexpandIcon: _propTypes2.default.string,
        expand: _propTypes2.default.bool,
        selected: _propTypes2.default.bool,
        level: _propTypes2.default.number
    };

    TreeNode.defaultProps = {
        label: '',
        expand: false,
        selected: false,
        icons: ['keyboard-arrow-right', 'keyboard-arrow-down']
    };
});
//# sourceMappingURL=TreeNode.js.map
